(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     35347,        980]
NotebookOptionsPosition[     33646,        921]
NotebookOutlinePosition[     33991,        936]
CellTagsIndexPosition[     33948,        933]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Below are provided specialized 3x3 and 2x2 eigensolvers for real symmetric \
matrices. These implement exact solution equations. As such, they are prone \
to round-off error. If you want accuracy, use an iterative solver.  If you \
want to see precisely how the exact solution works, then this notebook will \
provide a working example.\
\>", "Text",
 CellChangeTimes->{{3.5241109757540407`*^9, 3.524111089673557*^9}}],

Cell[CellGroupData[{

Cell["\<\
3x3 analytical eigensolver (warning: analytical is NOT best choice for \
numerical accuracy -- iterative is better for that purpose)\
\>", "Section",
 CellChangeTimes->{{3.5241109200028524`*^9, 3.5241109676185756`*^9}}],

Cell["\<\
The following is a specialized purely analytical eigensolver for real \
symmetric 3x3 matrices

The output is:
\tc = center of Mohr\[CloseCurlyQuote]s circle
\tr = radius of Mohr\[CloseCurlyQuote]s circle
\t\[Lambda]L= lowest eigenvalue
\t\[Lambda]H = highest eigenvalue
\tvL = eigenvector corresponding to the low eigenvalue
\tvH = eigenvector corresponding to the high eigenvalue\
\>", "Text",
 CellChangeTimes->{{3.5241096285329847`*^9, 3.5241096361874223`*^9}, {
  3.5241109087632093`*^9, 3.524110914450535*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigen3x3", "[", "A_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[DoubleStruckCapitalI]", "=", 
       RowBox[{"IdentityMatrix", "[", "3", "]"}]}], ",", 
      RowBox[{"zeroTensor", "=", 
       RowBox[{"ConstantArray", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "3"}], "}"}]}], "]"}]}], ",", "S", ",", 
      "sin3\[Theta]", ",", "r", ",", "\[Theta]", ",", "z", ",", "\[Lambda]L", 
      ",", "\[Lambda]M", ",", "\[Lambda]H", ",", "PH", ",", "PM", ",", "PL", 
      ",", "Er", ",", "E\[Theta]", ",", "Ez", ",", "cos3\[Theta]", ",", "I1", 
      ",", "J2", ",", "J3"}], "}"}], ",", 
    RowBox[{
     RowBox[{"z", "=", 
      FractionBox[
       RowBox[{"Tr", "[", "A", "]"}], 
       SqrtBox["3"]]}], ";", 
     RowBox[{"S", "=", 
      RowBox[{"A", "-", 
       FractionBox[
        RowBox[{"z", " ", "\[DoubleStruckCapitalI]"}], 
        SqrtBox["3"]]}]}], ";", 
     RowBox[{"r", "=", 
      SqrtBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", "i", "3"], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", "j", "3"], 
         SuperscriptBox[
          RowBox[{"S", "\[LeftDoubleBracket]", 
           RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "2"]}]}]]}], 
     ";", 
     RowBox[{"Ez", "=", 
      FractionBox["\[DoubleStruckCapitalI]", 
       SqrtBox["3"]]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"r", ">", "0"}], ",", 
       RowBox[{
        RowBox[{"Er", "=", 
         FractionBox["S", "r"]}], ";", 
        RowBox[{"sin3\[Theta]", "=", 
         RowBox[{"3", " ", 
          SqrtBox["6"], " ", 
          RowBox[{"Det", "[", "Er", "]"}]}]}], ";", 
        RowBox[{"cos3\[Theta]", "=", 
         SqrtBox[
          RowBox[{"1", "-", 
           SuperscriptBox["sin3\[Theta]", "2"]}]]}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"cos3\[Theta]", ">", "0"}], ",", 
          RowBox[{
           RowBox[{"\[Theta]", "=", 
            FractionBox[
             RowBox[{"ArcSin", "[", "sin3\[Theta]", "]"}], "3"]}], ";", 
           RowBox[{"\[Lambda]H", "=", 
            RowBox[{
             FractionBox["z", 
              SqrtBox["3"]], "+", 
             FractionBox[
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                  SqrtBox["3"]], "+", 
                 RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}]}], 
              SqrtBox["2"]]}]}], ";", 
           RowBox[{"\[Lambda]M", "=", 
            RowBox[{
             FractionBox["z", 
              SqrtBox["3"]], "-", 
             RowBox[{
              SqrtBox[
               FractionBox["2", "3"]], " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]}], ";", 
           RowBox[{"\[Lambda]L", "=", 
            RowBox[{
             FractionBox["z", 
              SqrtBox["3"]], "+", 
             FractionBox[
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                  SqrtBox["3"]], "-", 
                 RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}]}], 
              SqrtBox["2"]]}]}], ";", 
           RowBox[{"E\[Theta]", "=", 
            FractionBox[
             RowBox[{
              RowBox[{
               SqrtBox["6"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Er", ".", "Er"}], "-", 
                 FractionBox["\[DoubleStruckCapitalI]", "3"]}], ")"}]}], "-", 
              RowBox[{"sin3\[Theta]", " ", "Er"}]}], "cos3\[Theta]"]}], ";", 
           RowBox[{"PH", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                 SqrtBox["2"]], "+", 
                FractionBox[
                 RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                 SqrtBox["6"]]}], ")"}], " ", "Er"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                 SqrtBox["6"]], "-", 
                FractionBox[
                 RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                 SqrtBox["2"]]}], ")"}], " ", "E\[Theta]"}], "+", 
             FractionBox["Ez", 
              SqrtBox["3"]]}]}], ";", 
           RowBox[{"PM", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SqrtBox[
                FractionBox["2", "3"]]}], " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", "Er"}], "-", 
             RowBox[{
              SqrtBox[
               FractionBox["2", "3"]], " ", 
              RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", "E\[Theta]"}], "+", 
             FractionBox["Ez", 
              SqrtBox["3"]]}]}], ";", 
           RowBox[{"PL", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                  SqrtBox["2"]]}], "+", 
                FractionBox[
                 RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                 SqrtBox["6"]]}], ")"}], " ", "Er"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                FractionBox[
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                 SqrtBox["6"]], "+", 
                FractionBox[
                 RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                 SqrtBox["2"]]}], ")"}], " ", "E\[Theta]"}], "+", 
             FractionBox["Ez", 
              SqrtBox["3"]]}]}], ";"}], ",", 
          RowBox[{
           RowBox[{"E\[Theta]", "=", "zeroTensor"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"sin3\[Theta]", ">", "0"}], ",", 
             RowBox[{
              RowBox[{"\[Lambda]L", "=", 
               RowBox[{"\[Lambda]M", "=", 
                FractionBox[
                 RowBox[{"z", "-", 
                  FractionBox["r", 
                   SqrtBox["2"]]}], 
                 SqrtBox["3"]]}]}], ";", 
              RowBox[{"\[Lambda]H", "=", 
               FractionBox[
                RowBox[{"z", "+", 
                 RowBox[{
                  SqrtBox["2"], " ", "r"}]}], 
                SqrtBox["3"]]}], ";", 
              RowBox[{"PH", "=", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"\[DoubleStruckCapitalI]", "+", 
                  RowBox[{
                   SqrtBox["6"], " ", "Er"}]}], ")"}]}]}], ";", 
              RowBox[{"PM", "=", 
               RowBox[{"\[DoubleStruckCapitalI]", "-", "PH"}]}], ";", 
              RowBox[{"PL", "=", "zeroTensor"}]}], ",", 
             RowBox[{
              RowBox[{"\[Lambda]M", "=", 
               FractionBox[
                RowBox[{"z", "+", 
                 FractionBox["r", 
                  SqrtBox["2"]]}], 
                SqrtBox["3"]]}], ";", 
              RowBox[{"\[Lambda]L", "=", 
               RowBox[{"\[Lambda]H", "=", 
                FractionBox[
                 RowBox[{"z", "-", 
                  RowBox[{
                   SqrtBox["2"], " ", "r"}]}], 
                 SqrtBox["3"]]}]}], ";", 
              RowBox[{"PL", "=", 
               RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"\[DoubleStruckCapitalI]", "-", 
                  RowBox[{
                   SqrtBox["6"], " ", "Er"}]}], ")"}]}]}], ";", 
              RowBox[{"PM", "=", 
               RowBox[{"\[DoubleStruckCapitalI]", "-", "PL"}]}], ";", 
              RowBox[{"PH", "=", "zeroTensor"}]}], ",", 
             RowBox[{
              RowBox[{
              "Print", "[", "\"\<Arrived in unexpected branch\>\"", "]"}], 
              ";", 
              RowBox[{"Abort", "[", "]"}]}]}], "]"}]}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Er", "=", "zeroTensor"}], ";", 
        RowBox[{"E\[Theta]", "=", "zeroTensor"}], ";", 
        RowBox[{"\[Lambda]L", "=", 
         RowBox[{"\[Lambda]M", "=", 
          RowBox[{"\[Lambda]H", "=", 
           FractionBox["z", 
            SqrtBox["3"]]}]}]}]}]}], "]"}], ";", 
     RowBox[{"I1", "=", 
      RowBox[{"Tr", "[", "A", "]"}]}], ";", 
     RowBox[{"S", "=", 
      RowBox[{"A", "-", 
       FractionBox[
        RowBox[{"I1", " ", "\[DoubleStruckCapitalI]"}], "3"]}]}], ";", 
     RowBox[{"J2", "=", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"Tr", "[", 
        RowBox[{"S", ".", "S"}], "]"}]}]}], ";", 
     RowBox[{"J3", "=", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"Tr", "[", 
        RowBox[{"S", ".", "S", ".", "S"}], "]"}]}]}], ";", 
     RowBox[{"Return", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"I1", ",", "J2", ",", "J3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]L", ",", "\[Lambda]M", ",", "\[Lambda]H"}], 
           "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"PL", ",", "PM", ",", "PH"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Er", ",", "E\[Theta]", ",", "Ez"}], "}"}]}], "}"}]}], 
       "}"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5240936514991503`*^9, 3.5240936889332914`*^9}, {
  3.52409372300424*^9, 3.5240938033798375`*^9}, {3.524093855827837*^9, 
  3.5240938894687614`*^9}, {3.524093970624403*^9, 3.5240939795429134`*^9}, {
  3.5240940165070276`*^9, 3.5240940248765063`*^9}, {3.524094099478773*^9, 
  3.5240941008538523`*^9}, {3.5241090762133937`*^9, 3.524109083600816*^9}, {
  3.524109621888604*^9, 3.524109650751255*^9}, {3.524109708027531*^9, 
  3.5241097129228115`*^9}}],

Cell["Sample useage", "Text",
 CellChangeTimes->{{3.5241096641310205`*^9, 3.5241096666511645`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A", "=", 
   RowBox[{
    RowBox[{"(", GridBox[{
       {"1", "2", "0"},
       {"2", "4", "5"},
       {"0", "5", "6"}
      }], ")"}], "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"I1", ",", "J2", ",", "J3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Lambda]L", ",", "\[Lambda]M", ",", "\[Lambda]H"}], "}"}]}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"PL", ",", "PM", ",", "PH"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Er", ",", "E\[Theta]", ",", "Ez"}], "}"}]}], "}"}]}], "}"}], 
   "=", 
   RowBox[{"eigen3x3", "[", "A", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The Lode invariants are...\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Theta]", ",", "z"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<The corresponding Lode basis tensors are...\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"MatrixForm", "/@", 
    RowBox[{"N", "[", 
     RowBox[{"{", 
      RowBox[{"Er", ",", "E\[Theta]", ",", "Ez"}], "}"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The mechanics invariants are ...\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"I1", ",", "J2", ",", "J3"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The eigenvalues are ...\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"\[Lambda]L", ",", "\[Lambda]H", ",", "\[Lambda]M"}], "}"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<The corresponding eigenprojectors are...\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"MatrixForm", "/@", 
    RowBox[{"{", 
     RowBox[{"PL", ",", "PM", ",", "PH"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5241096699623537`*^9, 3.5241096914765844`*^9}, {
  3.524109921706753*^9, 3.5241100019143405`*^9}, {3.52411003757738*^9, 
  3.524110085099098*^9}, {3.5241101159208612`*^9, 3.524110196002442*^9}, {
  3.5241102326605387`*^9, 3.524110236450755*^9}, {3.524110745950897*^9, 
  3.524110747535988*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The Lode invariants are...\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "8.406346808612328`", ",", "0.2508787634174079`", ",", 
     "6.350852961085884`"}], "}"}]}],
  SequenceForm[
  "The Lode invariants are...", {8.406346808612328, 0.2508787634174079, 
   6.350852961085884}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5241101169859223`*^9, 3.5241101439154625`*^9}, 
   3.5241101979885554`*^9, 3.524110237077791*^9, {3.5241107368513765`*^9, 
   3.524110755287431*^9}}],

Cell[BoxData["\<\"The corresponding Lode basis tensors are...\"\>"], "Print",
 CellChangeTimes->{{3.5241101169859223`*^9, 3.5241101439154625`*^9}, 
   3.5241101979885554`*^9, 3.524110237077791*^9, {3.5241107368513765`*^9, 
   3.524110755289431*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.3172206342872578`"}], "0.23791547571544322`", "0.`"},
       {"0.23791547571544322`", "0.03965257928590706`", "0.5947886892886081`"},
       {"0.`", "0.5947886892886081`", "0.2775680550013503`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", "0.2939016185409179`"}], 
        RowBox[{"-", "0.44443659389114537`"}], "0.4749020055691671`"},
       {
        RowBox[{"-", "0.44443659389114537`"}], "0.22669850454528173`", 
        "0.07616352919505417`"},
       {"0.4749020055691671`", "0.07616352919505417`", "0.06720311399563657`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.5773502691896258`", "0.`", "0.`"},
       {"0.`", "0.5773502691896258`", "0.`"},
       {"0.`", "0.`", "0.5773502691896258`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Print",
 CellChangeTimes->{{3.5241101169859223`*^9, 3.5241101439154625`*^9}, 
   3.5241101979885554`*^9, 3.524110237077791*^9, {3.5241107368513765`*^9, 
   3.5241107552914314`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The mechanics invariants are ...\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"11.`", ",", "35.333333333333336`", ",", "55.25925925925928`"}], 
    "}"}]}],
  SequenceForm[
  "The mechanics invariants are ...", {11., 35.333333333333336`, 
   55.25925925925928}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5241101169859223`*^9, 3.5241101439154625`*^9}, 
   3.5241101979885554`*^9, 3.524110237077791*^9, {3.5241107368513765`*^9, 
   3.524110755292431*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The eigenvalues are ...\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2394516972093088`"}], ",", "10.276748254493578`", ",", 
     "1.9627034427157346`"}], "}"}]}],
  SequenceForm[
  "The eigenvalues are ...", {-1.2394516972093088`, 10.276748254493578`, 
   1.9627034427157346`}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5241101169859223`*^9, 3.5241101439154625`*^9}, 
   3.5241101979885554`*^9, 3.524110237077791*^9, {3.5241107368513765`*^9, 
   3.5241107552944317`*^9}}],

Cell[BoxData["\<\"The corresponding eigenprojectors are...\"\>"], "Print",
 CellChangeTimes->{{3.5241101169859223`*^9, 3.5241101439154625`*^9}, 
   3.5241101979885554`*^9, 3.524110237077791*^9, {3.5241107368513765`*^9, 
   3.5241107552954316`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.3506488353020668`", 
        RowBox[{"-", "0.3926305646708408`"}], "0.2711742415673506`"},
       {
        RowBox[{"-", "0.3926305646708408`"}], "0.43963859221418206`", 
        RowBox[{"-", "0.30364080775872565`"}]},
       {"0.2711742415673506`", 
        RowBox[{"-", "0.30364080775872565`"}], "0.20971257248375155`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.6300911617534376`", "0.3032954653223961`", 
        RowBox[{"-", "0.37561702616962456`"}]},
       {"0.3032954653223961`", "0.14599179431297035`", 
        RowBox[{"-", "0.18080390211807112`"}]},
       {
        RowBox[{"-", "0.37561702616962456`"}], 
        RowBox[{"-", "0.18080390211807112`"}], "0.22391704393359174`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.01926000294449548`", "0.0893350993484447`", "0.10444278460227403`"},
       {"0.0893350993484447`", "0.41436961347284756`", "0.4844447098767968`"},
       {"0.10444278460227403`", "0.4844447098767968`", "0.5663703835826567`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Print",
 CellChangeTimes->{{3.5241101169859223`*^9, 3.5241101439154625`*^9}, 
   3.5241101979885554`*^9, 3.524110237077791*^9, {3.5241107368513765`*^9, 
   3.524110755297432*^9}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
If eigenvectors are desired, they may be found by orthonormalizing the \
columns (or rows) of the Eigenprojectors. For single multiplicity \
eigenvalues, this process procduces only one nonzero vector. For this \
problem, for example,\
\>", "Text",
 CellChangeTimes->{{3.5241102591030507`*^9, 3.5241103133991566`*^9}, {
  3.524110820507161*^9, 3.5241108562752075`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"evecL", "=", 
  RowBox[{
   RowBox[{"Orthogonalize", "[", "PL", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"evecM", "=", 
  RowBox[{
   RowBox[{"Orthogonalize", "[", "PM", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"evecH", "=", 
  RowBox[{
   RowBox[{"Orthogonalize", "[", "PH", "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.524110291132883*^9, 3.5241104010631704`*^9}, {
  3.524110526078321*^9, 3.524110538111009*^9}, {3.524110658501895*^9, 
  3.5241106674294057`*^9}, {3.5241107985729065`*^9, 3.5241108033771815`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5921560903191544`", ",", 
   RowBox[{"-", "0.6630524807390301`"}], ",", "0.4579438529817292`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.524110302671543*^9, {3.524110336997506*^9, 3.524110372533539*^9}, 
   3.524110402854273*^9, 3.524110538917055*^9, 3.5241106684774656`*^9, 
   3.524110757908581*^9, 3.5241108048912683`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.7937828177489341`", ",", "0.3820887257077483`", ",", 
   RowBox[{"-", "0.47319873619187935`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.524110302671543*^9, {3.524110336997506*^9, 3.524110372533539*^9}, 
   3.524110402854273*^9, 3.524110538917055*^9, 3.5241106684774656`*^9, 
   3.524110757908581*^9, 3.524110804892268*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1387804126831142`", ",", "0.6437154755579882`", ",", 
   "0.7525758324465762`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.524110302671543*^9, {3.524110336997506*^9, 3.524110372533539*^9}, 
   3.524110402854273*^9, 3.524110538917055*^9, 3.5241106684774656`*^9, 
   3.524110757908581*^9, 3.5241108048932686`*^9}]
}, Open  ]],

Cell["\<\
The following confirms that the eigenvectors are indeed correct:\
\>", "Text",
 CellChangeTimes->{{3.5241111311609297`*^9, 3.524111147680875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Chop", "[", 
  RowBox[{
   RowBox[{"A", ".", "evecL"}], "-", 
   RowBox[{"\[Lambda]L", " ", "evecL"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{
   RowBox[{"A", ".", "evecM"}], "-", 
   RowBox[{"\[Lambda]M", " ", "evecM"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{
   RowBox[{"A", ".", "evecH"}], "-", 
   RowBox[{"\[Lambda]H", " ", "evecH"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5241105411281815`*^9, 3.524110586605783*^9}, {
  3.5241106201497016`*^9, 3.524110639413803*^9}, {3.5241107728124332`*^9, 
  3.524110777156682*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.5241105594282284`*^9, 3.524110588004863*^9}, {
  3.5241106404208612`*^9, 3.5241106702215652`*^9}, {3.5241107647709737`*^9, 
  3.5241108067073717`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.5241105594282284`*^9, 3.524110588004863*^9}, {
  3.5241106404208612`*^9, 3.5241106702215652`*^9}, {3.5241107647709737`*^9, 
  3.524110806708372*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.5241105594282284`*^9, 3.524110588004863*^9}, {
  3.5241106404208612`*^9, 3.5241106702215652`*^9}, {3.5241107647709737`*^9, 
  3.5241108067093725`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2x2 eigensolver", "Section",
 CellChangeTimes->{{3.524109090280198*^9, 3.524109093391376*^9}}],

Cell["\<\
The following is a specialized eigensolver for real symmetric 2x2 matrices

The output is:
\tc = center of Mohr\[CloseCurlyQuote]s circle
\tr = radius of Mohr\[CloseCurlyQuote]s circle
\t\[Lambda]L= lowest eigenvalue
\t\[Lambda]H = highest eigenvalue
\tvL = eigenvector corresponding to the low eigenvalue
\tvH = eigenvector corresponding to the high eigenvalue\
\>", "Text",
 CellChangeTimes->{{3.524109116278685*^9, 3.5241092483822412`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eigen2x2", "[", "A_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Hpt", ",", "Vpt", ",", "Ppt", ",", "\[Sigma]xx", ",", "\[Sigma]yy", ",",
       "\[Sigma]xy", ",", "c", ",", "\[Lambda]L", ",", "\[Lambda]H", ",", 
      "angH", ",", "angL", ",", "vH", ",", "vL"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\[Sigma]xx", "=", 
      RowBox[{"A", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", 
     RowBox[{"\[Sigma]yy", "=", 
      RowBox[{"A", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "2"}], "]"}], "]"}]}], ";", 
     RowBox[{"\[Sigma]xy", "=", 
      RowBox[{"A", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Hpt", "=", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]xx", ",", 
        RowBox[{"-", "\[Sigma]xy"}]}], "}"}]}], ";", 
     RowBox[{"Vpt", "=", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]yy", ",", "\[Sigma]xy"}], "}"}]}], ";", 
     RowBox[{"Ppt", "=", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]yy", ",", 
        RowBox[{"-", "\[Sigma]xy"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"c", "=", 
      FractionBox[
       RowBox[{"\[Sigma]xx", "+", "\[Sigma]yy"}], "2"]}], ";", 
     RowBox[{"r", "=", 
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"\[Sigma]xx", "-", "\[Sigma]yy"}], "2"], ")"}], "2"], "+", 
        SuperscriptBox["\[Sigma]xy", "2"]}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"\[Lambda]L", "=", 
      RowBox[{"c", "-", "r"}]}], ";", 
     RowBox[{"\[Lambda]H", "=", 
      RowBox[{"c", "+", "r"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"angH", "=", 
      RowBox[{
       FractionBox[
        RowBox[{"-", "1"}], "2"], 
       RowBox[{"ArcTan", "@@", "Hpt"}]}]}], ";", 
     RowBox[{"angL", "=", 
      RowBox[{"angH", "+", 
       FractionBox["\[Pi]", "2"]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vH", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", "angH", "]"}], ",", 
        RowBox[{"Sin", "[", "angH", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vL", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", "angL", "]"}], ",", 
        RowBox[{"Sin", "[", "angL", "]"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"c", ",", "r"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]L", ",", "\[Lambda]H"}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"vL", ",", "vH"}], "}"}]}], "}"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell["Sample useage", "Text",
 CellChangeTimes->{{3.5241091063111153`*^9, 3.5241091099353223`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", 
     RowBox[{"(", GridBox[{
        {"4.0", "5.0"},
        {"5.0", "3.0"}
       }], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"c", ",", "r"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]L", ",", "\[Lambda]H"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"vL", ",", "vH"}], "}"}]}], "}"}], "=", 
     RowBox[{"eigen2x2", "[", "A", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<The center and radius of Mohr's circle are \>\"", ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "r"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<The eigenvalues are \>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\[Lambda]L", ",", "\[Lambda]H"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<The corresponding eigenvectors are \>\"", ",", 
     RowBox[{"vL", "//", "MatrixForm"}], ",", " ", "\"\<  and\>\"", ",", " ", 
     RowBox[{"vH", "//", "MatrixForm"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.524109260409929*^9, 3.524109301383272*^9}, {
  3.5241093861431203`*^9, 3.524109590365801*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The center and radius of Mohr's circle are \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3.5`", ",", "5.024937810560445`"}], "}"}]}],
  SequenceForm[
  "The center and radius of Mohr's circle are ", {3.5, 5.024937810560445}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5241095715397243`*^9, 3.5241095924999237`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The eigenvalues are \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.524937810560445`"}], ",", "8.524937810560445`"}], "}"}]}],
  SequenceForm[
  "The eigenvalues are ", {-1.524937810560445, 8.524937810560445}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5241095715397243`*^9, 3.524109592500923*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The corresponding eigenvectors are \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         RowBox[{"-", "0.43318873048913437`"}]},
        {"0.9013032363068559`"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"  and\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0.9013032363068559`"},
        {"0.4331887304891343`"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["The corresponding eigenvectors are ", 
   MatrixForm[{-0.43318873048913437`, 0.9013032363068559}], "  and", 
   MatrixForm[{0.9013032363068559, 0.4331887304891343}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5241095715397243`*^9, 3.5241095925019236`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{707, 797},
WindowMargins->{{Automatic, 32}, {Automatic, 41}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 428, 7, 65, "Text"],
Cell[CellGroupData[{
Cell[1010, 31, 229, 4, 97, "Section"],
Cell[1242, 37, 526, 13, 173, "Text"],
Cell[1771, 52, 10230, 271, 726, "Input"],
Cell[12004, 325, 99, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[12128, 330, 2456, 70, 221, "Input"],
Cell[CellGroupData[{
Cell[14609, 404, 546, 13, 23, "Print"],
Cell[15158, 419, 249, 3, 23, "Print"],
Cell[15410, 424, 2603, 64, 100, "Print"],
Cell[18016, 490, 525, 12, 23, "Print"],
Cell[18544, 504, 566, 13, 23, "Print"],
Cell[19113, 519, 248, 3, 23, "Print"],
Cell[19364, 524, 2821, 67, 100, "Print"]
}, Open  ]]
}, Open  ]],
Cell[22212, 595, 379, 7, 47, "Text"],
Cell[CellGroupData[{
Cell[22616, 606, 663, 15, 72, "Input"],
Cell[23282, 623, 372, 8, 30, "Output"],
Cell[23657, 633, 368, 7, 30, "Output"],
Cell[24028, 642, 357, 8, 30, "Output"]
}, Open  ]],
Cell[24400, 653, 156, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[24581, 660, 609, 15, 72, "Input"],
Cell[25193, 677, 257, 5, 30, "Output"],
Cell[25453, 684, 255, 5, 30, "Output"],
Cell[25711, 691, 257, 5, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26017, 702, 100, 1, 71, "Section"],
Cell[26120, 705, 453, 11, 173, "Text"],
Cell[26576, 718, 2859, 81, 267, "Input"],
Cell[29438, 801, 99, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[29562, 806, 1392, 37, 185, "Input"],
Cell[CellGroupData[{
Cell[30979, 847, 391, 9, 23, "Print"],
Cell[31373, 858, 389, 9, 23, "Print"],
Cell[31765, 869, 1841, 47, 36, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
